@@ -1,5 +1,5 @@
 /*
-Copyright (c) 1997-2020, John M. Boyer
+Copyright (c) 1997-2021, John M. Boyer
 All rights reserved.
 See the LICENSE.TXT file for licensing information.
 */
@@ -20,8 +20,8 @@ void ProjectTitle()
 	// of Current, Revision and/or Age as documented in configure.ac
 
     Message("\n=================================================="
-            "\nThe Edge Addition Planarity Suite version 3.0.1.0"
-            "\nCopyright (c) 1997-2020 by John M. Boyer"
+            "\nThe Edge Addition Planarity Suite version 3.0.1.1"
+            "\nCopyright (c) 1997-2021 by John M. Boyer"
     		"\nContact info: jboyer at acm.org"
             "\n=================================================="
             "\n");
@@ -98,8 +98,8 @@ int helpMessage(char *param)
 	else if (strcmp(param, "-i") == 0 || strcmp(param, "-info") == 0)
 	{
 	    Message(
-		    "The Edge Addition Planarity Suite version 3.0.1.0\n"
-	    	"Copyright (c) 1997-2020, John M. Boyer\n"
+		    "The Edge Addition Planarity Suite version 3.0.1.1\n"
+	    	"Copyright (c) 1997-2021, John M. Boyer\n"
 		    "All rights reserved. \n"
 	    	"See the LICENSE.TXT file for licensing information. \n"
             "\n"
@@ -165,7 +165,7 @@ int helpMessage(char *param)
 	}
 
     FlushConsole(stdout);
-    return 0;
+    return OK;
 }
 
 /****************************************************************************
